==> haskell-hslua-classes-2.3.1-23.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-classes.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hslua-classes
version:              2.3.1
visibility:           public
id:                   hslua-classes-2.3.1-6dKeQUIbJbFJh9YBveBvy
key:                  hslua-classes-2.3.1-6dKeQUIbJbFJh9YBveBvy
license:              MIT
copyright:
    © 2007–2012 Gracjan Polak;
    © 2012–2016 Ömer Sinan Ağacan;
    © 2017-2024 Albert Krewinkel

maintainer:           tarleb@hslua.org
author:               Albert Krewinkel, Gracjan Polak, Ömer Sinan Ağacan
homepage:             https://hslua.org/
synopsis:             Type classes for HsLua
description:
    Type classes for convenient marshalling and calling of
    Lua functions.

category:             Foreign
abi:                  72114e48bf6f7863d976a566cb7b0761
exposed:              True
exposed-modules:
    HsLua.Class.Exposable HsLua.Class.Invokable HsLua.Class.Peekable
    HsLua.Class.Pushable HsLua.Class.Util HsLua.Classes

import-dirs:          /usr/lib/ghc-9.6.6/site-local/hslua-classes-2.3.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hslua-classes-2.3.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hslua-classes-2.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-classes
hs-libraries:         HShslua-classes-2.3.1-6dKeQUIbJbFJh9YBveBvy
depends:
    base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7
    exceptions-0.10.7 hslua-core-2.3.2-LsuRv5joEv2BEnjW1fCbrM
    hslua-marshalling-2.3.1-2wvb5zI3Ais62iyLUWMiUH text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-hslua-classes/html/hslua-classes.haddock

haddock-html:         /usr/share/doc/haskell-hslua-classes/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hslua-classes-2.3.1-24-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-classes.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hslua-classes
version:              2.3.1
visibility:           public
id:                   hslua-classes-2.3.1-CvdZaDG2CHK76U3CE1FtGI
key:                  hslua-classes-2.3.1-CvdZaDG2CHK76U3CE1FtGI
license:              MIT
copyright:
    © 2007–2012 Gracjan Polak;
    © 2012–2016 Ömer Sinan Ağacan;
    © 2017-2024 Albert Krewinkel

maintainer:           tarleb@hslua.org
author:               Albert Krewinkel, Gracjan Polak, Ömer Sinan Ağacan
homepage:             https://hslua.org/
synopsis:             Type classes for HsLua
description:
    Type classes for convenient marshalling and calling of
    Lua functions.

category:             Foreign
abi:                  b345b05e97a1ca8727dc8bb406ce5019
exposed:              True
exposed-modules:
    HsLua.Class.Exposable HsLua.Class.Invokable HsLua.Class.Peekable
    HsLua.Class.Pushable HsLua.Class.Util HsLua.Classes

import-dirs:          /usr/lib/ghc-9.6.6/site-local/hslua-classes-2.3.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hslua-classes-2.3.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hslua-classes-2.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-classes
hs-libraries:         HShslua-classes-2.3.1-CvdZaDG2CHK76U3CE1FtGI
depends:
    base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7
    exceptions-0.10.7 hslua-core-2.3.2-6IHXwFbRgmjH5Bn36TUerg
    hslua-marshalling-2.3.1-Lphd68rczTTD9xcjuNYtYD text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-hslua-classes/html/hslua-classes.haddock

haddock-html:         /usr/share/doc/haskell-hslua-classes/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
